@@ -36,6 +36,7 @@ log = get_logger()
     help='Format output',
 )
 @option('--raw', 'is_raw', is_flag=True, help='Dump raw json for further processing')
+@option('--params-columns',  help='A comma-delimited list of parameter names to show as columns')
 @pass_context
 def jobs(
     ctx,
@@ -51,6 +52,7 @@ def jobs(
     num,
     output,
     is_raw,
+    params_columns
 ):
     svc = ctx.obj.service
     if is_mine:
@@ -93,6 +95,9 @@ def jobs(
     ]
     if is_wide:
         fields.extend(['desc', 'context', 'complete_date', 'pod', '#proc'])
+    if params_columns:
+        for p in  params_columns.split(','):
+            fields.append(f"param_{p}")
     jobs_list = []
     for job in jobs:
         job_list = []
@@ -121,6 +126,9 @@ def jobs(
                     v = click.style("N/A", fg='yellow', bold=True)
                 else:
                     v = f"{job.cost_amount:.2f} {job.cost_currency}"
+            elif f.startswith('param_'):
+                param_name = f[6:]
+                v = job.details.get('launch_config', {}).get('nextflow_params', {}).get(param_name)
             job_list.append(v)
 
         jobs_list.append(job_list)
